@@ -10,7 +10,7 @@ from kombunicator.BaseConsumer import BaseConsumer
 class DirectConsumer(BaseConsumer):
 
     @match_typing
-    def __init__(self, connection, binding_key: str = '', accept: list = ['json']):
+    def __init__(self, connection, binding_key: str = '', accept: list = ['json'], is_rpc_server: bool = False):
         super().__init__()
 
         self.connection = connection
@@ -21,7 +21,14 @@ class DirectConsumer(BaseConsumer):
         else:
             self.binding_key = binding_key
 
-        self.queue = Queue(
-            name=self.binding_key,
-            auto_delete=True
-        )
+        if is_rpc_server:
+            self.queue = Queue(
+                name=self.binding_key,
+                auto_delete=False,
+                expires=30 * 24 * 60 * 60.0  # 30 days
+            )
+        else:
+            self.queue = Queue(
+                name=self.binding_key,
+                auto_delete=True
+            )
