@@ -1,6 +1,7 @@
 
-from threading import Thread
+from threading import Thread, Event
 from types import FunctionType, MethodType
+from typing import Union
 
 from kombu import Connection
 from strongtyping.strong_typing import match_typing
@@ -15,7 +16,7 @@ class MessageConsumer(Thread):
     @match_typing
     def __init__(self, connection_parameter: dict = {}, consumer_type: str = 'direct', exchange_name='',
                  binding_keys: list = [], q_unique=None, accept: list = ['json'],
-                 _thread_ready=None):
+                 _thread_ready=None, is_rpc=False):
         super().__init__()
         self.daemon = True
 
@@ -24,19 +25,20 @@ class MessageConsumer(Thread):
         self.binding_keys = binding_keys
         self.accept = accept
         self._thread_ready = _thread_ready
+        self._is_rpc_server = is_rpc
 
         if self.consumer_type == 'topic':
-            assert type(exchange_name) is str, f"'exchange_name' must be string"
-            assert type(q_unique) is str, f"'q_unique' must be string"
+            assert type(exchange_name) is str, "'exchange_name' must be string"
+            assert type(q_unique) is str, "'q_unique' must be string"
 
         if self.consumer_type == 'fanout':
-            assert type(exchange_name) is str, f"'exchange_name' must be string"
+            assert type(exchange_name) is str, "'exchange_name' must be string"
 
         self.exchange_name = exchange_name
         self.q_unique = q_unique
 
-    def register_message_handler(self, msg_handler):
-        assert type(msg_handler) is FunctionType or MethodType, "'msg_handler' must be function or method"
+    @match_typing
+    def register_message_handler(self, msg_handler: Union[FunctionType, MethodType]):
         self.msg_handler = msg_handler
 
     def _create_consumer(self, connection):
@@ -58,6 +60,7 @@ class MessageConsumer(Thread):
         elif self.consumer_type == 'direct':
             self.consumer = DirectConsumer(
                 binding_key=self.binding_keys[0],
+                is_rpc_server=self._is_rpc_server,
                 **consumer_base_params
             )
             self.consumer.process_message = self.msg_handler
@@ -87,9 +90,18 @@ class MessageConsumer(Thread):
             self._create_consumer(conn)
             self.consumer.run()
 
-    def stop(self):
+    def stop(self, ready=None):
         """
         Causes the RabbitMQ consumer to stop consuming
         and return. After that, the thread can be joined.
         """
+        if ready is not None and isinstance(ready, Event):
+            self._consumer_stopped = ready
+
+            # create a callback routine which sets the stop-event and
+            # attach it to the (currently running) consumer.
+            def _on_consume_end(connection, channel, stop_event=self._consumer_stopped):
+                stop_event.set()
+            self.consumer.on_consume_end = _on_consume_end
+
         self.consumer.should_stop = True
